using System;
using System.Data;

using System.Data.SqlClient;
using System.Configuration;
using System.Web;
using System.Web.UI;
using Sql.DataAccessLayer;
using System.Collections.Generic;
using System.Text;
/// <summary>
/// Summary description for AbuseReport
/// </summary>
public class AbuseReport
{
    // Note: Abuse Report Important Terms

    // It can be use for flag videos, blogs and other contents
    // It can also be use for (mark as spam) any content such as (comments, message)

    // contentid:
    // Unique ID of content that represent either video, blog, comment, message etc
    
    // Type:
    // ........... 0: Videos.
    // ........... 1: Channel Comments
    // ........... 2: User Messages
    // ........... 3: Group Topics
    // ........... 4: Video Comments
    // ........... 5: Photos
    // ........... 6: Photo Comments
    // ........... 7: Blogs
    // ........... 8: Blog Comments
    //............ 9: Photo Galleries
    // ........... 10: QA
    // ........... 11: QA Answer

    // New Type:
    //............ 4: Every type of comments (channel, videos, photos, blogs, galleries etc)

   	public AbuseReport()
	{
	}

    // Abuse Reporting Script -/ use in main content abouse reporting 
    // Version 2.0 added in VSK 5.3 or above
    public static string Process_V2(string content_username, long contentid, string reason, int type, int mediatype)
    {
        if (!HttpContext.Current.User.Identity.IsAuthenticated)
        {
            string sign_in = "<a href=\"" + Config.GetUrl() + "Login.aspx\" class=\"bold\">Sign In</a>";
            string sign_up = "<a href=\"" + Config.GetUrl() + "Register.aspx\" class=\"bold\">Sign Up</a>";
            return sign_in + " or " + sign_up + " to post report!";
        }
        string username = HttpContext.Current.User.Identity.Name;

        if (content_username == username)
        {
            return "You can't post abuse / spam report on your own content.";
        }

        if (AbuseReport.Check_UserName(username, contentid, type))
        {
            return "You already post abuse / spam report on this content.";
        }

        //***********************************
        // ENABLE comment if you want to validate report based on ip address
        //***********************************

        string ipaddress = HttpContext.Current.Request.ServerVariables["REMOTE_ADDR"];
        if (AbuseReport.Check_IPAddress(ipaddress, contentid, type))
        {
            return "Report already posted from this IP address.";
        }

        AbuseReport.Add(contentid, username, ipaddress, reason, type);

        int count_reports = AbuseReport.Count(contentid, type);
        if (count_reports > Config.Return_AbuseReport_Count())
        {
            int OldValue = 0;
            switch (type)
            {
                case 0:
                    // video
                    // Disable video if more than required people flag current video
                    OldValue = Convert.ToInt32(VideoBLL.Get_Field_Value(contentid, "isenabled"));
                    VideoBLL.Update_IsEnabled(contentid,OldValue, 0, content_username, mediatype);
                    break;
            }
           
        }
        return "Report has been submitted successfully!";
    }
    
    public static bool Add(long ContentID,string UserName, string IPAddress, string Reason,int Type)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Insert INTO abusereports(ContentID,UserName,IpAddress,Reason,AddedDate,Type)values(@ContentID,@UserName,@IpAddress,@Reason,@AddedDate,@Type)", new SqlParameter("@ContentID", ContentID), new SqlParameter("@UserName", UserName), new SqlParameter("@IpAddress", IPAddress), new SqlParameter("@Reason", Reason), new SqlParameter("@AddedDate", DateTime.Now), new SqlParameter("@Type", Type));
        return true;
    }
    
    // delete all reports related to content, e.g any video reports.
    public static bool Delete(long ContentID,int Type)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "DELETE FROM abusereports WHERE ContentID=@contentid AND type=@type", new SqlParameter("@contentid", ContentID), new SqlParameter("@type", Type));
        return true;
    }

    // delete single reports related to content
    public static bool Delete(long ReportID)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "DELETE FROM abusereports WHERE ReportID=@reportid",new SqlParameter("@reportid",ReportID));
        return true;
    }
    
    public static bool Check_UserName(string username,long ContentID,int Type)
    {
        int result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(username) FROM abusereports WHERE username=@username AND ContentID=@contentid AND Type=@type", new SqlParameter("@username", username), new SqlParameter("@contentid", ContentID), new SqlParameter("@type", Type)));
        if(result>0)
            return true;
        else
            return false;
    }
    
     public static bool Check_IPAddress(string ipaddress,long ContentID,int type)
    {
        int result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(username) FROM abusereports WHERE ipaddress=@ipaddress AND ContentID=@contentid",new SqlParameter("@ipaddress",ipaddress),new SqlParameter("@contentid",ContentID)));
        if(result>0)
            return true;
        else
            return false;
    }
    
    public static int Count(long ContentID,int type)
    {
        return Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT COUNT(reportid) from abusereports WHERE ContentID=@contentid AND type=@type",new SqlParameter("@type",type),new SqlParameter("@contentid",ContentID)));
    }

    public static DataSet Load_Video_Reports(long ContentID, int Type)
    {
        return (DataSet)SqlHelper.ExecuteDataset(Config.ConnectionString, CommandType.Text, "SELECT * from abusereports where ContentID=" + ContentID + " AND Type=" + Type + "");
    }

    public static List<Abuse_Struct> Load_Reports(string type)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        con.Open();
        System.Collections.Generic.List<Abuse_Struct> items = new System.Collections.Generic.List<Abuse_Struct>();
        Abuse_Struct str_ct = default(Abuse_Struct);
        //// generate query
        string _type = "";
        if (type != "all")
            _type = " WHERE type=" + type;

        string Query = "SELECT * from abusereports" + _type;
        SqlCommand cmd = new SqlCommand(Query, con);
        SqlDataReader reader = cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            str_ct = new Abuse_Struct();
            str_ct.ReportID = (long)reader["reportid"];
            str_ct.ContentID = (long)reader["contentid"];
            str_ct.UserName = reader["username"].ToString();
            str_ct.IPAddress = reader["ipaddress"].ToString();
            str_ct.Reason = reader["reason"].ToString();
            str_ct.AddedDate = (DateTime)reader["addeddate"];
            str_ct.Type = Convert.ToInt32(reader["type"]);
            items.Add(str_ct);
        }
        reader.Close();
        con.Close();
        return items;
    }

}
