using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.UI;
using Sql.DataAccessLayer;
using System.Collections.Generic;
using System.Text;
using System.Web.Caching;
using System.IO;
using System.Collections;
using System.Data.SqlClient;
/// <summary>
/// Summary description for VideoBLL
/// </summary>
public class VideoBLL
{

    // Note: Important Video Terms

    // type:
    // .............. 0: Videos (Default)
    // .............. 1: Audio Files // If audio plugin enabled

    // isPrivate:
    // ........... 0: Public Video
    // ........... 1: Restricted Video
    // ........... 2: Unlisted Video

    // isEnabled:
    // ........... 0: Disabled Video
    // ........... 1: Enabled Video

    // isPublished:
    // ........... 0: Video not published or encoded yet
    // ........... 1: Video published or encoded properly

    // isReviewed:
    // ........... 0: Video not reviewed yet
    // ........... 1: Video reviewed by administrator

    // isComments:
    // ........... 0: Disabled comments
    // ........... 1: Enabled comments

    // isRatings:
    // ........... 0: Disabled ratings
    // ........... 1: Enabled ratings

    // isFeatured:
    // ........... 0: Normal Videos
    // ........... 1: Featured Videos   
    // ........... 3: Premium Videos

    // isAdult:
    // ........... 0: Normal Video
    // ........... 1: Adult Video -> In case user redirected to adult content warning section. User must accept 18 year notification before continue.

    // For public video you must add the following filter action in your SQL query

    // isPriavate=0 AND isEnabled=1 AND isPublished=1 AND isReviewed=1


    // istagsreviewed
    // ............ 0: tags processed
    // ............ 1: not yet processed

    // New Actions Avaialble in VSK 7.0 or later
    // contentid ---- 0 (default), id of content which have assign this record (e.g group, user profile etc)
    // content type --- 0 (default)
    // .............. 1: group
    // .............. 2: User profile


	public VideoBLL()
	{
	    
	}

    // ************************************************************************************************************************************
    // ************************************************************************************************************************************
    // Video Data Manipulation Section
    // ************************************************************************************************************************************
    // ************************************************************************************************************************************
    #region Data Manipulation
    public static void Process_Video_File_Information(Video_Struct vd)
    {
        StringBuilder str = new StringBuilder();
        // insert new record
        str.Append("Update videos set VideoFileName=@VideoFileName,ThumbFileName=@ThumbFileName,originalvideofilename=@originalvideofilename Where VideoID=@VideoID");
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, str.ToString(), new SqlParameter("@VideoFileName", vd.VideoFileName), new SqlParameter("@ThumbFileName", vd.ThumbFileName), new SqlParameter("@originalvideofilename", vd.OriginalVideoFileName), new SqlParameter("@VideoID", vd.VideoID));
    }

    public static void Process_Video_Cloud_Information(Video_Struct vd)
    {
        StringBuilder str = new StringBuilder();
        // insert new record
        str.Append("Update videos set flv_url=@flv_url,thumb_url=@thumb_url,org_url=@org_url Where VideoID=@VideoID");
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, str.ToString(), new SqlParameter("@flv_url", vd.FLV_Url), new SqlParameter("@thumb_url", vd.Thumb_Url), new SqlParameter("@org_url", vd.Org_Url), new SqlParameter("@VideoID", vd.VideoID));
    }

    // Process_Info() is used to post video information or update video information in database
    public static long Process_Info(Video_Struct vd, bool isUpdate)
    {
        // *********************************************************//
        // SCREENING Data Script: Updated in VSK 5.2
        // *********************************************************//
        if (Config.Get_ScreeningOption() == 1)
        {
            // screening, matching and replacing enabled
            // the following script will screen content with matching words e.g "apple" -> "a***e"
            vd.Tags = DictionaryBLL.Process_Screening(vd.Tags);
            vd.Description = DictionaryBLL.Process_Screening(vd.Description);
            vd.Title = DictionaryBLL.Process_Screening(vd.Title);
        }
        // *********************************************************//
        // *********************************************************//

        // int Mode = CategoriesBLL.Get_Mode(0, vd.Categories);
        // format video description information
        vd.Description = UtilityBLL.Process_Content(vd.Description);
        long VID = 0;
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        StringBuilder str = new StringBuilder();
        if (isUpdate)
        {
            // update existing record
            if (vd.VideoID == 0)
            {
                return 0;
            }

            
            str.Append("Update videos set Categories=@Categories,Title=@Title,Description=@Description,Tags=@Tags,isPrivate=@isPrivate,Mode=@Mode WHERE VideoID=@VideoID");
            SqlCommand cmd = new SqlCommand(str.ToString(), con);
            
            cmd.CommandType = CommandType.Text;
            cmd.Parameters.Add(new SqlParameter("@Categories", vd.Categories));
            cmd.Parameters.Add(new SqlParameter("@Title", vd.Title));
            cmd.Parameters.Add(new SqlParameter("@Description", vd.Description));
            cmd.Parameters.Add(new SqlParameter("@Tags", vd.Tags));
            cmd.Parameters.Add(new SqlParameter("@isPrivate", vd.isPrivate));
            cmd.Parameters.Add(new SqlParameter("@Mode", vd.Mode));
            cmd.Parameters.Add(new SqlParameter("@VideoID", vd.VideoID));
           
            if (con.State != ConnectionState.Open) 
                con.Open();
            cmd.ExecuteNonQuery();
        }
        else
        {
            // insert new record
            // assign current record with culture specific content (default english en)
            string culturename = "en";
           
            // generate sql query
            str.Append("Insert Into videos(CategoryID,Categories,UserName,Title,Description,Tags,Duration,VideoFileName,ThumbFileName,Date_Added,isEnabled,isPrivate,isResponse,response_videoid,duration_sec,");
            str.Append("originalvideofilename,ispublished,isreviewed,flv_url,org_url,thumb_url,embed_script,isexternal,ipaddress,type,youtubeid,istagsreviewed,language,mode,authkey,galleryid)values(");
            str.Append("@CategoryID,@Categories,@UserName,@Title,@Description,@Tags,@Duration,@VideoFileName,@ThumbFileName,@Date_Added,@isEnabled,@isPrivate,@isresponse,@response_videoid,@duration_sec,@originalvideofilename,@ispublished,@isreviewed,@flv_url,@org_url,");
            str.Append("@thumb_url,@embed_script,@isexternal,@ipaddress,@type,@youtubeid,@istagsreviewed,@language,@mode,@authkey,@galleryid);Select SCOPE_IDENTITY();");
            // execute sql query
           
            SqlCommand cmd = new SqlCommand(str.ToString(), con);
            cmd.CommandType = CommandType.Text;
            cmd.Parameters.Add(new SqlParameter("@CategoryID", vd.CategoryID));
            cmd.Parameters.Add(new SqlParameter("@Categories", vd.Categories));
            cmd.Parameters.Add(new SqlParameter("@UserName", vd.UserName));
            cmd.Parameters.Add(new SqlParameter("@Title", vd.Title));
            cmd.Parameters.Add(new SqlParameter("@Description", vd.Description));
            cmd.Parameters.Add(new SqlParameter("@Tags", vd.Tags));
            cmd.Parameters.Add(new SqlParameter("@Duration", vd.Duration));
            cmd.Parameters.Add(new SqlParameter("@VideoFileName", vd.VideoFileName));
            cmd.Parameters.Add(new SqlParameter("@ThumbFileName", vd.ThumbFileName));
            cmd.Parameters.Add(new SqlParameter("@isEnabled", vd.isEnabled));
            cmd.Parameters.Add(new SqlParameter("@isPrivate", vd.isPrivate));
            cmd.Parameters.Add(new SqlParameter("@isresponse", vd.isResponse));
            cmd.Parameters.Add(new SqlParameter("@response_videoid", vd.Response_VideoID));

            cmd.Parameters.Add(new SqlParameter("@duration_sec", vd.Duration_Sec));
            cmd.Parameters.Add(new SqlParameter("@originalvideofilename", vd.OriginalVideoFileName));
            cmd.Parameters.Add(new SqlParameter("@ispublished", vd.isPublished));
            cmd.Parameters.Add(new SqlParameter("@isreviewed", vd.isReviewed));
            cmd.Parameters.Add(new SqlParameter("@flv_url", vd.FLV_Url));
            cmd.Parameters.Add(new SqlParameter("@org_url", vd.Org_Url));
            cmd.Parameters.Add(new SqlParameter("@thumb_url", vd.Thumb_Url));
            cmd.Parameters.Add(new SqlParameter("@embed_script", vd.Embed_Script));
            cmd.Parameters.Add(new SqlParameter("@isexternal", vd.isExternal));
            cmd.Parameters.Add(new SqlParameter("@ipaddress", vd.IPAddress));
            cmd.Parameters.Add(new SqlParameter("@type", vd.Type));
            cmd.Parameters.Add(new SqlParameter("@youtubeid", vd.YoutubeID));
            cmd.Parameters.Add(new SqlParameter("@istagsreviewed", vd.isTagsreViewed));

            cmd.Parameters.Add(new SqlParameter("@mode", vd.Mode));
            cmd.Parameters.Add(new SqlParameter("@language", culturename));
            cmd.Parameters.Add(new SqlParameter("@galleryid", vd.GalleryID));
            cmd.Parameters.Add(new SqlParameter("@authkey", vd.AuthKey));

            cmd.Parameters.Add(new SqlParameter("@Date_Added", DateTime.Now));
            if (con.State != ConnectionState.Open) 
                con.Open();
            VID = Convert.ToInt64(cmd.ExecuteScalar());
           
        }
       
        //// update member video statistics if user upload new video
        if (!isUpdate)
        {
            if (vd.isReviewed == 1 && vd.isPrivate == 0 && vd.isEnabled == 1 && vd.isPublished == 1)
            {
                string fieldname = "stat_videos";
                if (vd.Type == 1)
                    fieldname = "stat_audios";
                // changes happend
                int count = Convert.ToInt32(members.Return_Value(vd.UserName, fieldname));
                count++;
                members.Update_Value(vd.UserName, fieldname, count.ToString());
            }
        }
        return VID;
    }

    // This update is only for pubplishing pending videos (unpublished videos only)
    public static bool Update(Video_Struct vd)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set duration=@duration,duration_sec=@duration_sec,videofilename=@videofilename,thumbfilename=@thumbfilename,ispublished=@ispublished,isenabled=@isenabled,flv_url=@flv_url,thumb_url=@thumb_url,org_url=@org_url where VideoID=@VideoID", new SqlParameter("@VideoID", vd.VideoID), new SqlParameter("@duration", vd.Duration), new SqlParameter("@duration_sec", vd.Duration_Sec), new SqlParameter("@videofilename", vd.VideoFileName), new SqlParameter("@thumbfilename", vd.ThumbFileName), new SqlParameter("@ispublished", vd.isPublished), new SqlParameter("@flv_url", vd.FLV_Url), new SqlParameter("@thumb_url", vd.Thumb_Url), new SqlParameter("@org_url", vd.Org_Url), new SqlParameter("@isenabled", vd.isEnabled));
        if (vd.UserName != "")
        {
            int count = VideoBLL.Count(vd.UserName, vd.Type); // count user enabled videos
            string fieldname = "stat_videos";
            if (vd.Type == 1)
                fieldname = "stat_audios";
            members.Update_Value(vd.UserName, fieldname, count.ToString());
        }
        
        return true;
    }

    // Update video information - myaccount section - edit video
    public static bool Update_Video_Info(Video_Struct vd)
    {
        // *********************************************************//
        // SCREENING Data Script: Updated in VSK 5.2
        // *********************************************************//
        if (Config.Get_ScreeningOption() == 1)
        {
            // screening, matching and replacing enabled
            // the following script will screen content with matching words e.g "apple" -> "a***e"
            vd.Tags = DictionaryBLL.Process_Screening(vd.Tags);
            vd.Description = DictionaryBLL.Process_Screening(vd.Description);
            vd.Title = DictionaryBLL.Process_Screening(vd.Title);
        }
        // *********************************************************//
        // *********************************************************//
        StringBuilder str = new StringBuilder();
        // update existing record
        if (vd.VideoID == 0)
        {
            return false;
        }
        //int Mode = CategoriesBLL.Get_Mode(0, vd.Categories);
        // format video description information
        vd.Description = UtilityBLL.Process_Content(vd.Description);
        // stored procedure in database exist: VSK_Videos_Update_MyAccount
        string query = "Update videos set title=@title,description=@description,tags=@tags,isPrivate=@isPrivate,iscomments=@iscomments,isresponse=@isresponse,isratings=@isratings,categories=@categories,Mode=@Mode WHERE VideoID=@VideoID;";
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, query, new SqlParameter("@VideoID", vd.VideoID), new SqlParameter("@title", vd.Title), new SqlParameter("@description", vd.Description), new SqlParameter("@tags", vd.Tags), new SqlParameter("@isPrivate", vd.isPrivate), new SqlParameter("@isratings", vd.isRatings), new SqlParameter("@isresponse", vd.isResponse), new SqlParameter("@iscomments", vd.isComments), new SqlParameter("@categories", vd.Categories), new SqlParameter("@Mode", vd.Mode));

        return true;
    }
   
    // Remove Video Data both from Database and folder (image, videos etc)
    public static void RemoveVideo(long VideoID,int type)
    {
        string flvvideoname = "";
        string originalvideoname = "";
        string thumbname = "";
        string username = "";

        List<Video_Struct> _lst = VideoBLL.Fetch_Video_Data(VideoID);
        if (_lst.Count > 0)
        {
            flvvideoname = _lst[0].VideoFileName;
            originalvideoname = _lst[0].OriginalVideoFileName;
            thumbname = _lst[0].ThumbFileName;
            username = _lst[0].UserName;
        }

        // Delete Record
        VideoBLL.Delete(VideoID,username,type);
    }


    public static bool Update_VideoInfo_Adm(Video_Struct vd)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set title=@title,description=@description,tags=@tags,categoryid=@categoryid,categories=@categories,views=@views,downloads=@downloads,liked=@liked,disliked=@disliked,mode=@mode where VideoID=@VideoID", new SqlParameter("@VideoID", vd.VideoID), new SqlParameter("@title", vd.Title), new SqlParameter("@description", vd.Description), new SqlParameter("@tags", vd.Tags), new SqlParameter("@categoryid", vd.CategoryID),new SqlParameter("@categories",vd.Categories),new SqlParameter("@liked",vd.Liked),new SqlParameter("@views",vd.Views),new SqlParameter("@disliked",vd.Disliked),new SqlParameter("@downloads",vd.Downloads),new SqlParameter("@mode",vd.Mode));
        return true;
    }

    // approve or reject all gallery videos or audio
    public static void Update_isApproved_All(long GalleryID, string UserName, int Status,int Type)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set isreviewed=@isreviewed where galleryid=@galleryid", new SqlParameter("@galleryid", GalleryID), new SqlParameter("@isreviewed", Status));
        // update user stats
        string _field = "stat_videos";
        if (Type == 1) // album type -> to media type conversion
            Type = 0;
        else
        {
            Type = 1;
            _field = "stat_audios";
        }

        int count_user_media = Count(GalleryID, 1, 1, Type);
        members.Update_Value(UserName, _field, count_user_media.ToString());
    }

    // enable / disable all gallery videos or audio
    public static void Update_isEnabled_All(long GalleryID, string UserName, int Status, int Type)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set isenabled=@isenabled where galleryid=@galleryid", new SqlParameter("@galleryid", GalleryID), new SqlParameter("@isenabled", Status));
        // update user stats
        string _field = "stat_videos";
        if (Type == 1) // album type -> to media type conversion
            Type = 0;
        else
        {
            Type = 1;
            _field = "stat_audios";
        }

        int count_user_media = Count(GalleryID, 1, 1, Type);
        members.Update_Value(UserName, _field, count_user_media.ToString());
    }
    public static int Count(long galleryid, int isreviewed, int isdisabled,int type)
    {
        string _filter = "";
        string _approvefilter = "";

        if (isreviewed != 2)
            _filter = " AND isreviewed=" + isreviewed;
        if (isdisabled != 2)
            _approvefilter = " AND isenabled=" + isdisabled;
        return Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT count(videoid) from videos where galleryid=@galleryid AND type=@type" + _filter + "" + _approvefilter, new SqlParameter("@galleryid", galleryid), new SqlParameter("@type", type)));
    }
    public static bool Update_Video(long VideoID, int CategoryID, string Title, string Description, string tags, int isPrivate)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set CategoryID=@CategoryID,Title=@Title,Description=@Description,Tags=@Tags,isPrivate=@isPrivate WHERE VideoID=@VideoID", new SqlParameter("@VideoID", VideoID), new SqlParameter("@CategoryID", CategoryID), new SqlParameter("@Title", Title), new SqlParameter("@Description", Description), new SqlParameter("@Tags", tags), new SqlParameter("@isPrivate", isPrivate));
       return true;
    }


    // for cloud storage
    public static bool Update_Selected_Thumb(long VideoID, string ThumbFileName, string Thumb_Url)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set ThumbFileName=@ThumbFileName,Thumb_Url=@Thumb_Url WHERE VideoID=@VideoID", new SqlParameter("@VideoID", VideoID), new SqlParameter("@ThumbFileName", ThumbFileName),new SqlParameter("@Thumb_Url",Thumb_Url));
        return true;
    }

    // Delete video where statistic update is required
    public static bool Delete(long VideoID,string UserName,int type)
    {
        // update all response key to none
        if(type==0) // video support response videos
           SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set response_videoid=0 where response_videoid=@videoid",new SqlParameter("@videoid",VideoID));

        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Delete FROM videos WHERE VideoID=@videoid",new SqlParameter("@videoid",VideoID));
        if (UserName != "")
        {
            string fieldname = "stat_videos";
            if (type == 1)
                fieldname = "stat_audios";
            // changes happend
            int count = Convert.ToInt32(members.Return_Value(UserName, fieldname));
            count--;
            members.Update_Value(UserName, fieldname, count.ToString());
        }
       
       
        return true;
    }

    // Delete video where no statistic update is required
    // Mostly in case of youtube embed videos
    public static bool Delete(long VideoID)
    {       
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Delete FROM videos WHERE VideoID=@videoid",new SqlParameter("@videoid",VideoID));
        return true;
    }

    public static bool Update_IsEnabled(long VideoID,int OldValue, int NewValue,string UserName,int type)
    {
        Update_Field(VideoID, NewValue.ToString(), "isEnabled");
        if (NewValue != OldValue)
        {
            string fieldname = "stat_videos";
            if (type == 1)
                fieldname = "stat_audios";
            // changes happend
            int count = Convert.ToInt32(members.Return_Value(UserName, fieldname));
            if (NewValue == 1)
                count++;
            else
                count--;
            members.Update_Value(UserName, fieldname, count.ToString());
        }
        return true;
    }

    public static bool Update_IsPrivate(long VideoID, int OldValue, int NewValue,string UserName,int type)
    {   
        Update_Field(VideoID, NewValue.ToString(), "isPrivate");
        if (NewValue != OldValue)
        {
            string fieldname = "stat_videos";
            if (type == 1)
                fieldname = "stat_audios";
            // changes happend
            int count = Convert.ToInt32(members.Return_Value(UserName, fieldname));
            if (NewValue == 1)
                count--; // video is marked as private
            else
                count++; // video is marked as public
            members.Update_Value(UserName, fieldname, count.ToString());
        }
        return true;
    }

    public static bool Update_IsPublished(long VideoID, int Value, string UserName,int type)
    {
        Update_Field(VideoID, Value.ToString(), "ispublished");
        if (Value == 1)
        {
            //  video is published successfully
            string fieldname = "stat_videos";
            if (type == 1)
                fieldname = "stat_audios";
            // changes happend
            int count = Convert.ToInt32(members.Return_Value(UserName, fieldname));
            count++;
            members.Update_Value(UserName, fieldname, count.ToString());
        }
        return true;
    }

    public static bool Update_IsReviewed(long VideoID,int OldValue, int NewValue, string UserName,int type)
    {
        Update_Field(VideoID, NewValue.ToString(), "isreviewed");
        if (NewValue != OldValue)
        {
            string fieldname = "stat_videos";
            if (type == 1)
                fieldname = "stat_audios";
            // changes happend
            int count = Convert.ToInt32(members.Return_Value(UserName, fieldname));
            if (NewValue == 1)
                count++;
            else
                count--;
            members.Update_Value(UserName, fieldname, count.ToString());
        }

        if (NewValue == 1)
        {
            // send notification mail to user when record approved by admin
            string url = "<a href=\"" + Config.GetUrl("myaccount/videos/") + "\">Manage Videos</a>";
            MailProcess.User_Mail_Content_Action(UserName, "videos", url, "approved");
        }
        return true;
    }

    public bool Review_Video(long VideoID)
    {
        bool flg = false;
        DataSet ds = (DataSet)SqlHelper.ExecuteDataset(Config.ConnectionString, CommandType.Text, "SELECT isenabled,ispublished,isreviewed from videos where VideoID=@VideoID", new SqlParameter("@VideoID", VideoID));
        if (ds.Tables[0].Rows.Count > 0)
        {
            int isenabled = int.Parse(ds.Tables[0].Rows[0]["isenabled"].ToString());
            int ispublished = int.Parse(ds.Tables[0].Rows[0]["ispublished"].ToString());
            int isreviewed = int.Parse(ds.Tables[0].Rows[0]["isreviewed"].ToString());
            if (isenabled == 1 && ispublished == 1 && isreviewed == 1)
                flg = true;
            else
                flg = false;
        }
        return flg;
    }
    
    public static bool Update_Responses(long VideoID)
    {
        // count responses
        int count = Convert.ToInt32(Get_Field_Value(VideoID, "responses"));
        count = count + 1;
        Update_Field(VideoID, count.ToString(), "responses");
        return true;
    }

	#endregion


    // ************************************************************************************************************************************
    // ************************************************************************************************************************************
    // Video Action Section
    // ************************************************************************************************************************************
    // ************************************************************************************************************************************
  
    #region Perform Actions

    // count user enabled videos
    public static int Count(string username,int type)
    {
        return Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT count(VideoID) from videos where UserName=@username AND type=@type AND isPrivate=0 AND isEnabled=1 AND ispublished=1 AND isreviewed=1",new SqlParameter("@type",type),new SqlParameter("@username",username)));
    }
    
    public static int Increment_Responses(long VideoID)
    {
        int current_responses = Convert.ToInt32(Get_Field_Value(VideoID, "responses"));
        current_responses = current_responses + 1;
        Update_Field(VideoID, current_responses.ToString(), "responses");
        return current_responses;
    }
      
    public static bool Update_Field(long videoid, string value, string FieldName)
    {
        //SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.StoredProcedure, "VSK_Videos_UpdateAction",new SqlParameter("@FieldName",FieldName), new SqlParameter("@videoid", videoid), new SqlParameter("@FieldValue", value));
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos Set " + FieldName + "=@FieldValue WHERE videoid=@videoid", new SqlParameter("@videoid", videoid), new SqlParameter("@FieldValue", value));
        return true;
    }

    public static bool Update_Field(long videoid, DateTime value, string FieldName)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set " + FieldName + "=@value where videoid=@videoid", new SqlParameter("@videoid", videoid), new SqlParameter("@value", value));
        return true;
    }

    public static string Get_Field_Value(long VideoID, string FieldName)
    {
        //return SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.StoredProcedure, "VSK_Videos_FetchFieldValue", new SqlParameter("@videoid", VideoID), new SqlParameter("@FieldName", FieldName)).ToString();
        return SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT " + FieldName + " FROM videos WHERE videoid=@videoid", new SqlParameter("@videoid", VideoID)).ToString();
    }
    // process video rating
    public static double Post_Rating(long VideoID, int current_rating, int total_ratings, double ratings)
    {
        // increment 
        total_ratings = total_ratings + 1;
        ratings = ratings + current_rating;
        double average_rating = (double)Math.Round(ratings / total_ratings, 2);
        // update rating
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set ratings=" + ratings + ",total_rating=" + total_ratings + ",avg_rating=" + average_rating + " where VideoID=" + VideoID + "");
        return average_rating;
    }

    public static bool Validate_VideoID(long VideoID)
    {
        int result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(VideoID) from videos where VideoID=" + VideoID + " AND isenabled=1 AND isprivate=0 AND ispublished=1 AND isreviewed=1"));
        if (result > 0)
            return true;
        else
            return false;
     }

	#endregion
  

    // ************************************************************************************************************************************
    // ************************************************************************************************************************************
    // Normal Load Operation - > Dataset
    // ************************************************************************************************************************************
    // ************************************************************************************************************************************


   
    #region Normal Video Loading -> Dataset
    public static DataSet Return_Operation_Values(long VideoID)
    {
        return (DataSet)SqlHelper.ExecuteDataset(Config.ConnectionString, CommandType.Text, "SELECT isEnabled,isComments,isReviewed,isexternal,isratings,isadult,isfeatured from videos where VideoID=" + VideoID + "");
    }
	#endregion

    // ************************************************************************************************************************************
    // ************************************************************************************************************************************
    // Core Data Fetching SDK (Videos & Audio Files)
    // Updated VSK 7.0 - June 2012
    // ************************************************************************************************************************************
    // ************************************************************************************************************************************

    #region Core Loading Script
    //**************************************************************************************
    // Core Engine for generating cached and non cached photo listings
    //**************************************************************************************

    public List<Video_Struct> Load_Videos_V4(Video_Struct vd)
    {
        if (!vd.isCache || Config.GetCacheDuration() == 0)
        {
            return Fetch_Videos_V4(vd);
        }
        else
        {
            StringBuilder cache = new StringBuilder();
            // generate cache key for different version of contents
            string lang = "";
           

            cache.Append("ld_vd_v3_" + vd.CategoryID + "" + vd.isFeatured + "" + vd.Type + "" + vd.UserName.ToLower() + "" + vd.Month + "" + vd.Year + "" + vd.Filter + "" + vd.isEnabled + "" + vd.isReviewed + "" + vd.isPrivate + "" + vd.isAdult + "" + vd.isExternal + "" + vd.DateFilter + "" + UtilityBLL.ReplaceSpaceWithHyphin(vd.Order.ToLower()) + "" + vd.PageNumber + "" + lang + "" + vd.Mode);
            if (vd.Term != "")
                cache.Append(UtilityBLL.ReplaceSpaceWithHyphin(vd.Term.ToLower()));


            if (HttpContext.Current.Cache[cache.ToString()] == null)
                HttpContext.Current.Cache.Add(cache.ToString(), Fetch_Videos_V4(vd), null, DateTime.Now.AddMinutes(Config.GetCacheDuration()), TimeSpan.Zero, CacheItemPriority.High, null);

            List<Video_Struct> _list = (List<Video_Struct>)(HttpContext.Current.Cache[cache.ToString()]);
            return _list;
        }
    }

    // Non Cache Version of Load Photo Records
    public List<Video_Struct> Fetch_Videos_V4(Video_Struct vd)
    {
        // month > 0 // archive enabled
        // filter > 0 // today, this week, this month filter is enabled
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        StringBuilder query = new StringBuilder();
        string llikedscript = "";
        if (vd.LoadLiked)
            llikedscript = " INNER JOIN user_ratings as r ON r.itemid=v.videoid ";
        string lfavoritescript = "";
        if (vd.LoadFavorites)
            lfavoritescript = " INNER JOIN favorites as f ON f.videoid=v.videoid ";
        string logic = Process_Videos_V3_Logic(vd);
        // filter option is used to filter records based on viewed records today, this week, this month, all time
        string _fields = "v.VideoID,v.title,v.username,v.duration,v.views,v.downloads,v.thumbfilename,v.thumb_url,v.date_added,v.isexternal,v.embed_script,v.isreviewed,v.isenabled,v.galleryid,v.ispublished";

        string _pubscript = "v.ispublished=" + vd.isPublished;
        if (vd.isPublished == 2)
            _pubscript = "v.ispublished<>2";
        switch (vd.Filter)
        {
            case 0:
                // all time viewed (no viewed filter)
                query.Append(_fields + " FROM videos as v " + lfavoritescript + "" + llikedscript + " WHERE " + _pubscript + " " + logic);
                break;
            case 1:
                // today viewed records
                query.Append(_fields + " FROM videos as v INNER JOIN view_stat_today as ve ON ve.contentid=v.videoid " + lfavoritescript + "" + llikedscript + " WHERE ve.itemtype=1 and " + _pubscript + " " + logic);
                query.Append(" " + Config.Prepare_DateDiff("ve.added_date", 0) + " ");
                break;
            case 2:
                // this week viewed records
                query.Append(_fields + " FROM videos as v INNER JOIN view_stat_thisweek as ve ON ve.contentid=v.videoid " + lfavoritescript + "" + llikedscript + " WHERE ve.itemtype=1 and " + _pubscript + " " + logic);
                query.Append(" " + Config.Prepare_DateDiff("ve.added_date", 3) + " ");
                break;
            case 3:
                // this month viewed records
                query.Append(_fields + " FROM videos as v INNER JOIN view_stat_thismonth as ve ON ve.contentid=v.videoid " + lfavoritescript + "" + llikedscript + " WHERE ve.itemtype=1 and " + _pubscript + " " + logic);
                query.Append(" " + Config.Prepare_DateDiff("ve.added_date", 4) + " ");
                break;
        }

        // implement paging script for differnt data sources.
        switch (Config.Return_PaginationType())
        {
            case 0:
                // SQL SERVER 2005 or Later Supported Query
                str.Append(Pagination_Process.Prepare_SQLSERVER2005_Pagination(query.ToString(), vd.Order, vd.PageNumber, vd.PageSize));
                break;
            case 1:
                // MySQL Supported Query
                string mysql_query = "SELECT " + query.ToString() + " ORDER BY " + vd.Order;
                str.Append(Pagination_Process.Prepare_MySQL_Pagination(mysql_query, vd.PageNumber, vd.PageSize));
                break;
            case 2:
                // SQL SERVER 2000 Supported Query
                string normal_query = "SELECT " + query.ToString() + " ORDER BY " + vd.Order;
                str.Append(normal_query);
                break;
        }
     
        // execute sql query
        SqlCommand cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["VideoID"];
            _item.GalleryID = (long)reader["GalleryID"];
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.Date_Added = (DateTime)reader["date_added"];
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.Embed_Script = reader["embed_script"].ToString();
            _item.isReviewed = Convert.ToInt32(reader["isreviewed"]);
            _item.isEnabled = Convert.ToInt32(reader["isenabled"]);
            _item.isPublished = Convert.ToInt32(reader["ispublished"]);
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    // cache version of count photos (used in shared photo listings e.g main listings)
    public int Cache_Count_Videos_V4(Video_Struct vd)
    {
        if (!vd.isCache || Config.GetCacheDuration() == 0)
        {
            return Count_Videos_V4(vd);
        }
        else
        {
            StringBuilder cache = new StringBuilder();
            // generate cache unique key for each type of loading
            string lang = "";
           
            cache.Append("ld_vd_cnt_v3_" + vd.CategoryID + "" + vd.isFeatured + "" + vd.Type + "" + vd.UserName.ToLower() + "" + vd.Month + "" + vd.Year + "" + vd.Filter + "" + vd.isEnabled + "" + vd.isReviewed + "" + vd.isPrivate + "" + vd.isAdult + "" + vd.isExternal + vd.SearchType + "" + vd.DateFilter + "" + lang + "" + vd.Mode);
            if (vd.Term != "")
                cache.Append(UtilityBLL.ReplaceSpaceWithHyphin(vd.Term.ToLower()));

            if (HttpContext.Current.Cache[cache.ToString()] == null)
                HttpContext.Current.Cache.Add(cache.ToString(), Count_Videos_V4(vd), null, DateTime.Now.AddMinutes(Config.GetCacheDuration()), TimeSpan.Zero, CacheItemPriority.High, null);

            return Convert.ToInt32(HttpContext.Current.Cache[cache.ToString()]);
        }
    }

    // non cache version of counter photos (used in very rarely accessed photo listings e.g user photo albums)
    public int Count_Videos_V4(Video_Struct vd)
    {
        StringBuilder str = new StringBuilder();
        string llikedscript = "";
        if (vd.LoadLiked)
            llikedscript = " INNER JOIN user_ratings as r ON r.itemid=v.videoid ";
        string lfavoritescript = "";
        if (vd.LoadFavorites)
            lfavoritescript = " INNER JOIN favorites as f ON f.videoid=v.videoid ";
        string _pubscript = "v.ispublished=" + vd.isPublished;
        if (vd.isPublished == 2)
            _pubscript = "v.ispublished<>2";
        string logic = Process_Videos_V3_Logic(vd);
        // filter option is used to filter records based on viewed records today, this week, this month, all time
        switch (vd.Filter)
        {
            case 0:
                // all time viewed (no viewed filter)
                str.Append("SELECT Count(v.videoid) from videos as v " + llikedscript + "" + lfavoritescript + " WHERE " + _pubscript + " " + logic);
                break;
            case 1:
                // today viewed records
                str.Append("SELECT Count(v.videoid) from videos as v INNER JOIN view_stat_today as ve ON ve.contentid=v.videoid " + llikedscript + "" + lfavoritescript + " WHERE ve.itemtype=1 and " + _pubscript + " " + logic);
                str.Append(" " + Config.Prepare_DateDiff("ve.added_date", 0) + " ");
                break;
            case 2:
                // this week viewed records
                str.Append("SELECT Count(v.videoid) from videos as v INNER JOIN view_stat_thisweek as ve ON ve.contentid=v.videoid " + llikedscript + "" + lfavoritescript + " WHERE ve.itemtype=1 and " + _pubscript + " " + logic);
                str.Append(" " + Config.Prepare_DateDiff("ve.added_date", 3) + " ");
                break;
            case 3:
                // this month viewed records
                str.Append("SELECT Count(v.videoid) from videos as v INNER JOIN view_stat_thismonth as ve ON ve.contentid=v.videoid " + llikedscript + "" + lfavoritescript + " WHERE ve.itemtype=1 and " + _pubscript + " " + logic);
                str.Append(" " + Config.Prepare_DateDiff("ve.added_date", 4) + " ");
                break;
        }


        return Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, str.ToString()));
    }

    // The following function load specific number of records without any pagination. e.g Fetching top 8 recently added photos
    // Cache Version
    public List<Video_Struct> Load_Videos_Limit(Video_Struct vd)
    {
        if (!vd.isCache || Config.GetCacheDuration() == 0)
        {
            return Fetch_Videos_Limit(vd);
        }
        else
        {
            // cache implementation
            StringBuilder cache = new StringBuilder();
            string lang = "";
          

            cache.Append("ft_vd_lm_" + vd.CategoryID + "" + vd.isFeatured + "_" + vd.Type + "" + vd.UserName + "" + vd.Month + "" + vd.Year + "" + vd.Filter + "" + vd.isEnabled + "" + vd.isReviewed + "" + vd.isPrivate + "" + vd.isAdult + "" + vd.isExternal + "" + vd.PageSize + "" + vd.SearchType + "" + vd.PageNumber + "" + vd.DateFilter + "" + UtilityBLL.ReplaceSpaceWithHyphin(vd.Order.ToLower()) + "" + lang + "" + vd.Mode);
            if (vd.Term != "")
                cache.Append(UtilityBLL.ReplaceSpaceWithHyphin(vd.Term.ToLower()));


            if (HttpContext.Current.Cache[cache.ToString()] == null)
                HttpContext.Current.Cache.Add(cache.ToString(), Fetch_Videos_Limit(vd), null, DateTime.Now.AddMinutes(Config.GetCacheDuration()), TimeSpan.Zero, CacheItemPriority.High, null);

            List<Video_Struct> _list = (List<Video_Struct>)(HttpContext.Current.Cache[cache.ToString()]);
            return _list;
        }
    }

    // The following function load specific number of records without any pagination. e.g Fetching top 8 recently added photos
    // Non Cache Version
    public List<Video_Struct> Fetch_Videos_Limit(Video_Struct vd)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        string llikedscript = "";
        if (vd.LoadLiked)
            llikedscript = " INNER JOIN user_ratings as r ON r.itemid=v.videoid ";
        string lfavoritescript = "";
        if (vd.LoadFavorites)
            lfavoritescript = " INNER JOIN favorites as f ON f.videoid=v.videoid ";
        // generate sql query
        string logic = Process_Videos_V3_Logic(vd);
        StringBuilder str = new StringBuilder();
        StringBuilder query = new StringBuilder();
        string _fields = "v.VideoID,v.title,v.username,v.duration,v.views,v.downloads,v.thumbfilename,v.thumb_url,v.date_added,v.isexternal,v.embed_script,v.isreviewed,v.isenabled,v.galleryid";
        switch (vd.Filter)
        {
            case 0:
                // all time viewed (no viewed filter)
                query.Append(_fields + " FROM videos as v " + llikedscript + "" + lfavoritescript + " WHERE v.ispublished=1 " + logic);
                break;
            case 1:
                // today viewed records
                query.Append(_fields + " FROM videos as v " + llikedscript + "" + lfavoritescript + " INNER JOIN view_stat_today as ve ON ve.contentid=v.videoid WHERE ve.itemtype=1 and v.ispublished=1 " + logic);
                query.Append(" " + Config.Prepare_DateDiff("ve.added_date", 0) + " ");
                break;
            case 2:
                // this week viewed records
                query.Append(_fields + " FROM videos as v " + llikedscript + "" + lfavoritescript + " INNER JOIN view_stat_thisweek as ve ON ve.contentid=v.videoid WHERE ve.itemtype=1 and v.ispublished=1 " + logic);
                query.Append(" " + Config.Prepare_DateDiff("ve.added_date", 3) + " ");
                break;
            case 3:
                // this month viewed records
                query.Append(_fields + " FROM videos as v " + llikedscript + "" + lfavoritescript + " INNER JOIN view_stat_thismonth as ve ON ve.contentid=v.videoid WHERE ve.itemtype=1 and v.ispublished=1 " + logic);
                query.Append(" " + Config.Prepare_DateDiff("ve.added_date", 4) + " ");
                break;
        }

        switch (Config.Return_PaginationType())
        {
            case 0:
                // SQL SERVER 2005 or Later Supported Query
                str.Append(Pagination_Process.Prepare_SQLSERVER2005_Pagination(query.ToString(), vd.Order, vd.PageNumber, vd.PageSize));
                break;
            case 1:
                // MySQL Supported Query
                string mysql_query = "SELECT " + query.ToString() + " ORDER BY " + vd.Order;
                str.Append(Pagination_Process.Prepare_MySQL_Pagination(mysql_query, vd.PageNumber, vd.PageSize));
                break;
            case 2:
                // SQL SERVER 2000 Supported Query
                string normal_query = "SELECT " + query.ToString() + " ORDER BY " + vd.Order;
                str.Append(normal_query);
                break;
        }
        //str.Append(" ORDER BY " + order + " LIMIT " + records);
        // execute sql query
        SqlCommand cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["VideoID"];
            _item.GalleryID = (long)reader["galleryid"];
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.Date_Added = (DateTime)reader["date_added"];
            _item.isReviewed = Convert.ToInt32(reader["isreviewed"]);
            _item.isEnabled = Convert.ToInt32(reader["isenabled"]);
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.Embed_Script = reader["embed_script"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    private string Process_Videos_V3_Logic(Video_Struct vd)
    {
        StringBuilder script = new StringBuilder();
        if (vd.Term != "" || vd.CategoryID != 0 || vd.isFeatured != 2 || vd.Type != 2 || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isPrivate != 3 || vd.isExternal != 3 || vd.DateFilter > 0 || vd.Filter > 0 || vd.Mode > 0 || vd.GalleryID > 0)
        {
            if (vd.LoadFavorites)
                script.Append("AND f.type=0 AND"); // type=1; represent video or audio type in favorite table
            else if (vd.LoadLiked)
                script.Append("AND r.type=0 AND r.rating=0 AND"); // type=0 represent video or audio type in ratings / votes / liked, where r.rating=0 represent liked (0: liked or voted up, 1: disliked or voted down)
            else
                script.Append("AND"); // no filter isenabled
        }
        if (vd.GalleryID > 0)
        {
            script.Append(" v.galleryid=" + vd.GalleryID + "");
            if (vd.Term != "" || vd.CategoryID != 0 || vd.isFeatured != 2 || vd.Type != 2 || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isPrivate != 3 || vd.isExternal != 3 || vd.DateFilter > 0 || vd.Filter > 0 || vd.Mode > 0)
                script.Append(" AND");
        }
        if (vd.isPrivate != 3)
        {
            script.Append(" v.isprivate=" + vd.isPrivate + "");
            if (vd.Term != "" || vd.CategoryID != 0 || vd.isFeatured != 2 || vd.Type != 2 || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0 || vd.Mode > 0)
                script.Append(" AND");
        }

        if (vd.Mode > 0)
        {
            script.Append(" v.mode=" + vd.Mode + "");
            if (vd.Term != "" || vd.CategoryID != 0 || vd.isFeatured != 2 || vd.Type != 2 || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.CategoryID != 0)
        {
            script.Append(" v.CategoryID=" + vd.CategoryID + "");
            if (vd.Term != "" || vd.isFeatured != 2 || vd.Type != 2 || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }

        if (vd.isFeatured != 2)
        {
            script.Append(" v.isfeatured=" + vd.isFeatured + "");
            if (vd.Term != "" || vd.Type != 2 || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }

        if (vd.Type != 2)
        {
            script.Append(" v.type=" + vd.Type + "");
            if (vd.Term != "" || vd.UserName != "" || vd.Month > 0 || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }

        if (vd.Month > 0 && vd.Year > 0)
        {
            // archive option (month and year both)
            script.Append(" Year(v.date_added)=" + vd.Year + " AND MONTH(v.date_added)= " + vd.Month);
            if (vd.Term != "" || vd.UserName != "" || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        else if (vd.Year > 0)
        {
            // archive option (only year)
            script.Append(" Year(v.date_added)=" + vd.Year + "");
            if (vd.Term != "" || vd.UserName != "" || vd.isEnabled != 2 || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.isEnabled != 2)
        {
            // archive option
            script.Append(" v.isenabled=" + vd.isEnabled);
            if (vd.Term != "" || vd.UserName != "" || vd.isReviewed != 2 || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.isReviewed != 2)
        {
            // archive option
            script.Append(" v.isreviewed=" + vd.isReviewed);
            if (vd.Term != "" || vd.UserName != "" || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.UserName != "")
        {
            if (vd.LoadFavorites)
                script.Append(" f.username='" + vd.UserName + "'"); // load user favorites
            else if (vd.LoadLiked)
                script.Append(" r.username='" + vd.UserName + "'"); // load user liked 
            else
                script.Append(" v.username='" + vd.UserName + "'"); // load user normal videos or audio files
            if (vd.Term != "" || vd.isAdult != 2 || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.isAdult != 2)
        {
            // archive option
            script.Append(" v.isadult=" + vd.isAdult + "");
            if (vd.Term != "" || vd.isExternal != 3 || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.isExternal != 3)
        {
            // archive option
            script.Append(" v.isexternal=" + vd.isExternal + "");
            if (vd.Term != "" || vd.DateFilter > 0)
                script.Append(" AND");
        }
        if (vd.DateFilter != 0)
        {
            switch (vd.DateFilter)
            {
                case 1:
                    // today records
                    script.Append(" " + Config.Prepare_DateDiff("v.date_added", 0) + " ");
                    break;
                case 2:
                    // this week records
                    script.Append(" " + Config.Prepare_DateDiff("v.date_added", 1) + " ");
                    break;
                case 3:
                    // this month records
                    script.Append(" " + Config.Prepare_DateDiff("v.date_added", 2) + " ");
                    break;
            }
            if (vd.Term != "")
                script.Append(" AND");
        }
        if (vd.Term != "")
        {
            switch (vd.SearchType)
            {
                case 0:
                    // categorymatch
                    script.Append(Config.CategorySearchScript(vd.Term.Trim(), "v."));
                    break;
                case 1:
                    // tag match
                    script.Append(Config.TagSearchScript(vd.Term.Trim(), "v."));
                    break;
                case 2:
                    // category or tag match
                    script.Append(" (v.categories like '%" + vd.Term.Trim() + "%' OR v.tags like '%" + vd.Term.Trim() + "%')");
                    break;
                case 3:
                    script.Append(Config.BroadSearchScript(vd.Term.Trim(), "v.", "v.title"));
                    break;
            }
        }
        // Filter AND
        if (vd.Filter > 0)
        {
            script.Append(" AND");
        }
        return script.ToString();
    }

    //**************************************************************************************
    // Close Core Engine for generating cached and non cached photo listings
    //************************************************************************************** 
    #endregion

    #region Admin Loading Script

    // Load photos in admin section
    public static List<Video_Struct> Load_Videos(string search, string username, string categoryid, string categories, int isEnabled, int isComment, int isreviewed, int isadult, int isfeatured,int isprivate, int isaudio, int isexternal, int filteroption, string order, int PageNumber, int PageSize, int Mode, long AlbumID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // Query Building
        StringBuilder str = new StringBuilder();
        StringBuilder query = new StringBuilder();
        string logic = Return_Video_Admin_Logic(search, username, categoryid, categories, isEnabled, isComment, isreviewed, isadult,isfeatured,isprivate,isaudio,isexternal, filteroption,Mode,AlbumID);
        query.Append("VideoID,title,username,duration,views,downloads,thumbfilename,videofilename,originalvideofilename,thumb_url,date_added,isenabled,isreviewed,isexternal,embed_script,galleryid FROM videos WHERE ispublished=1 " + logic);
       
        // implement paging script for differnt data sources.
        switch (Config.Return_PaginationType())
        {
            case 0:
                // SQL SERVER 2005 or Later Supported Query
                str.Append(Pagination_Process.Prepare_SQLSERVER2005_Pagination(query.ToString(), order, PageNumber, PageSize));
                break;
            case 1:
                // MySQL Supported Query
                string mysql_query = "SELECT " + query.ToString() + " ORDER BY " + order;
                str.Append(Pagination_Process.Prepare_MySQL_Pagination(mysql_query, PageNumber, PageSize));
                break;
            case 2:
                // SQL SERVER 2000 Supported Query
                string normal_query = "SELECT " + query.ToString() + " ORDER BY " + order;
                str.Append(normal_query);
                break;
        }
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["VideoID"];
            _item.GalleryID = (long)reader["galleryid"];
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.VideoFileName = reader["videofilename"].ToString();
            _item.OriginalVideoFileName = reader["originalvideofilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.Date_Added = (DateTime)reader["date_added"];
            _item.isEnabled = Convert.ToInt32(reader["isenabled"]);
            _item.isReviewed = Convert.ToInt32(reader["isreviewed"]);
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.Embed_Script = reader["embed_script"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;

    }

    // advance counting with different settings
    public static int Count_Videos(string search, string username, string categoryid, string categories, int isEnabled, int isComment, int isreviewed, int isadult, int isfeatured, int isprivate, int isaudio,int isexternal, int filteroption,int Mode,long AlbumID)
    {
        StringBuilder query = new StringBuilder();
        string logic =Return_Video_Admin_Logic(search, username, categoryid, categories, isEnabled, isComment, isreviewed, isadult, isfeatured,isprivate,isaudio,isexternal, filteroption,Mode,AlbumID);
        query.Append("SELECT Count(videoid) FROM videos  WHERE ispublished=1 " + logic);
        return Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, query.ToString()));
    }

    // Admin photo search script
    public static string Return_Video_Admin_Logic(string search, string username, string categoryid, string categories, int isEnabled, int isComment, int isreviewed, int isadult, int isfeatured, int isprivate, int isaudio, int isexternal, int filteroption, int Mode, long AlbumID)
    {
        StringBuilder query = new StringBuilder();

        if (search != "" || username != "" || categoryid != "" || categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || isexternal !=3 || filteroption != 0 || Mode > 0 || AlbumID > 0)
            query.Append(" AND");
        if (search != "")
        {
            query.Append(" (title like '%" + search + "%'");
            query.Append(" OR description like '%" + search + "%'");
            query.Append(" OR username like '%" + search + "%'");
            query.Append(" OR tags like '%" + search + "%')");
            if (username != "" || categoryid != "" || categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || isexternal != 3 || filteroption != 0 || Mode > 0 || AlbumID > 0)
                query.Append(" AND");
        }
        if (AlbumID > 0)
        {
            query.Append(" galleryid=" + AlbumID + "");
            if (username != "" || categoryid != "" || categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || isexternal != 3 || filteroption != 0 || Mode > 0)
                query.Append(" AND");
        }
        if (isexternal != 3)
        {
            query.Append(" isexternal=" + isexternal + "");
            if (username != "" || categoryid != "" || categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0 || Mode >0)
                query.Append(" AND");
        }
        if (Mode > 0)
        {
            query.Append(" mode=" + Mode + "");
            if (username != "" || categoryid != "" || categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (username != "")
        {
            query.Append(" username='" + username + "'");
            if (categoryid != "" || categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (categoryid != "")
        {
            query.Append(" categoryid=" + categoryid + "");
            if (categories != "" || isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (categories != "")
        {
            if (categories.Contains(","))
            {
                // multiple selected categories.
                query.Append(" (");
                string[] arr = categories.ToString().Split(char.Parse(","));
                int i = 0;

                if (arr.Length > 0)
                {

                    for (i = 0; i <= arr.Length - 1; i++)
                    {
                        string _name = arr[i].ToString().Trim();
                        if (i == 0)
                            query.Append(" categories like '%" + _name + "%'");
                        else
                            query.Append(" OR categories like '%" + _name + "%'");
                    }
                }
                query.Append(")");
            }
            else
            {
                query.Append(" categories like '%" + categories + "%'");
            }
            if (isEnabled != 2 || isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isEnabled != 2)
        {
            query.Append(" isenabled=" + isEnabled + "");
            if (isComment != 2 || isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isComment != 2)
        {
            query.Append(" iscomments=" + isComment + "");
            if (isreviewed != 2 || isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isreviewed != 2)
        {
            query.Append(" isreviewed=" + isreviewed + "");
            if (isadult != 2 || isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isadult != 2)
        {
            query.Append(" isadult=" + isadult + "");
            if (isfeatured != 2 || isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isfeatured != 2)
        {
            query.Append(" isfeatured=" + isfeatured + "");
            if (isprivate != 3 || isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isprivate != 3)
        {
            query.Append(" isprivate=" + isprivate + "");
            if (isaudio != 2 || filteroption != 0)
                query.Append(" AND");
        }
        if (isaudio != 2)
        {
            query.Append(" type=" + isaudio + "");
            if (filteroption != 0)
                query.Append(" AND");
        }
        if (filteroption != 0)
        {
            switch (filteroption)
            {
                case 1:
                    // today records
                    query.Append(" " + Config.Prepare_DateDiff("date_added", 0) + " ");
                    break;
                case 2:
                    // this week records
                    query.Append(" " + Config.Prepare_DateDiff("date_added", 1) + " ");
                    break;
                case 3:
                    // this month records
                    query.Append(" " + Config.Prepare_DateDiff("date_added", 2) + " ");
                    break;
            }
        }
        return query.ToString();
    }

    #endregion
    //**********************************************************************************************************************************
    //**********************************************************************************************************************************
    // ReadOnly Data Retrieval and Cache Management
    //**********************************************************************************************************************************
    //**********************************************************************************************************************************

    #region Advance Video Loading - > Readonly / Cache
	 
    public List<Video_Struct> Fetch_Record_v2(long VideoID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        // TSQL Version
        //str.Append("SELECT u.stat_Videos,u.stat_audios,v.VideoID,v.Liked,v.Disliked,v.isfeatured,v.title,v.username,v.categoryid,v.categories,v.description,v.tags,v.flv_url,v.videofilename,v.response_videoid,v.youtubeid,v.views,v.downloads,v.comments,v.favorites,v.responses,v.duration,v.iscomments,v.isratings,v.thumbfilename,v.thumb_url,v.date_added,v.isexternal,v.embed_script,v.isadult,v.duration_sec,v.isEnabled,v.isreviewed FROM videos as v INNER JOIN users as u on u.username=v.username WHERE v.ispublished=1 AND v.VideoID=" + VideoID + "");
        // execute sql query
        try
        {
            //SqlCommand video_cmd = new SqlCommand("VSK_Videos_Fetch", con);
            //video_cmd.CommandType = CommandType.StoredProcedure;
            SqlCommand video_cmd = new SqlCommand("SELECT u.stat_Videos,u.stat_audios,v.VideoID,v.Liked,v.Disliked,v.isfeatured,v.title,v.username,v.categoryid,v.categories,v.description,v.tags,v.flv_url,v.videofilename,v.response_videoid,v.youtubeid,v.views,v.downloads,v.comments,v.favorites,v.responses,v.duration,v.iscomments,v.isratings,v.thumbfilename,v.thumb_url,v.date_added,v.isexternal,v.embed_script,v.isadult,v.duration_sec,v.isEnabled,v.isreviewed,v.total_rating,v.ratings,v.avg_rating,v.galleryid FROM videos as v INNER JOIN users as u on u.username=v.username WHERE v.ispublished=1 AND v.VideoID=@VID", con);
            video_cmd.CommandType = CommandType.Text;
            video_cmd.Parameters.Add(new SqlParameter("@VID", VideoID));
            SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
            while (reader.Read())
            {
                _item = new Video_Struct();
                _item.Title = reader["title"].ToString();
                _item.GalleryID = (long)reader["galleryid"];
                _item.UserName = reader["username"].ToString();
                _item.Description = reader["description"].ToString();
                _item.Tags = reader["tags"].ToString();
                _item.VideoFileName = reader["videofilename"].ToString();
                _item.Response_VideoID = (int)reader["response_videoid"];
                _item.Duration = reader["duration"].ToString();
                _item.Duration_Sec = Convert.ToInt32(reader["duration_sec"]);
                _item.Views = (int)reader["views"];
                _item.Downloads = (int)reader["downloads"];
                _item.Comments = (int)reader["comments"];
                _item.Favorites = (int)reader["favorites"];
                _item.Responses = (int)reader["responses"];
                _item.YoutubeID = reader["youtubeid"].ToString();
                _item.ThumbFileName = reader["thumbfilename"].ToString();
                _item.FLV_Url = reader["flv_url"].ToString();
                _item.Thumb_Url = reader["thumb_url"].ToString();
                _item.Date_Added = (DateTime)reader["date_added"];
                _item.isExternal = Convert.ToInt32(reader["isexternal"]);
                _item.isComments = Convert.ToInt32(reader["iscomments"]);
                _item.isRatings = Convert.ToInt32(reader["isratings"]);
                _item.Embed_Script = reader["embed_script"].ToString();
                _item.isAdult = Convert.ToInt32(reader["isadult"]);
                _item.isEnabled = Convert.ToInt32(reader["isenabled"]);
                _item.isFeatured = Convert.ToInt32(reader["isfeatured"]);
                _item.isReviewed = Convert.ToInt32(reader["isreviewed"]);
                // user related
                _item.Uploaded_Videos = (int)reader["stat_Videos"];
                _item.Uploaded_Audio = (int)reader["stat_audios"];
                // category related
                //_item.CategoryID = Convert.ToInt32(reader["categoryid"]);
                _item.Categories = reader["categories"].ToString();
                _item.Liked = Convert.ToInt32(reader["liked"]);
                _item.Disliked = Convert.ToInt32(reader["disliked"]);
                _item.Avg_Rating = Convert.ToDouble(reader["avg_rating"]);
                _item.Ratings = Convert.ToDouble(reader["ratings"]);
                _item.Total_Rating = Convert.ToInt32(reader["total_rating"]);
                 _items.Add(_item);
            }
            reader.Close();
            con.Close(); 
            con.Dispose();
        }
        catch (Exception ex)
        {
        }
        finally
        {
            con.Close(); 
            con.Dispose();
        }
       

        return _items;
    }
  
    public List<Video_Struct> Fetch_Record_SM(long VideoID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT title,description, username,views,downloads,comments,iscomments,responses,duration,thumbfilename,thumb_url,date_added,isexternal,embed_script FROM videos WHERE isEnabled=1 AND ispublished=1 AND isreviewed=1 AND VideoID=" + VideoID + "");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.Comments = (int)reader["comments"];
            _item.Responses = (int)reader["responses"];
            _item.isComments = Convert.ToInt32(reader["iscomments"]);
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.Date_Added = (DateTime)reader["date_added"];
            _item.isExternal = int.Parse(reader["isexternal"].ToString());
            _item.Embed_Script = reader["embed_script"].ToString();
            _item.Description = reader["description"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    public static long Count_Videos(string categoryid)
    {
        StringBuilder query = new StringBuilder();
        query.Append("SELECT Count(VideoID) FROM videos WHERE isEnabled=1 AND ispublished=1 AND isreviewed=1 AND type=0");
        if (categoryid != "all")
            query.Append(" AND categoryid=" + categoryid);

        return Convert.ToInt64(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, query.ToString()));

    }
    
    // Get video information for admin section
    public List<Video_Struct> Get_Information(long VideoID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT v.title,v.description,v.username,v.mode,v.categoryid,v.tags,v.categories,v.flv_url,v.thumb_url,v.videofilename,v.thumbfilename,v.response_videoid,v.isadult,v.isfeatured,v.isreviewed,v.liked,v.disliked,v.views,v.downloads,v.comments,v.favorites,v.responses,v.isenabled,v.date_added,v.isexternal,v.embed_script,v.isreviewed,v.duration_sec,v.type FROM videos as v WHERE v.VideoID=" + VideoID + "");
              
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.Title = reader["title"].ToString();
            _item.Description = reader["description"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.CategoryID = int.Parse(reader["categoryid"].ToString());
            _item.Tags = reader["tags"].ToString();
            _item.FLV_Url = reader["flv_url"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.VideoFileName = reader["videofilename"].ToString();
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Response_VideoID = (int)reader["response_videoid"];
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.isFeatured =Convert.ToInt32(reader["isfeatured"]);
            _item.isAdult = Convert.ToInt32(reader["isadult"]);
            _item.isReviewed = Convert.ToInt32(reader["isReviewed"]);
            _item.Duration_Sec = Convert.ToInt32(reader["duration_sec"]);
            _item.Liked = (int)reader["Liked"];
            _item.Disliked = (int)reader["Disliked"];
            _item.Comments = (int)reader["comments"];
            _item.Favorites = (int)reader["favorites"];
            _item.Responses = (int)reader["responses"];
            _item.Date_Added = (DateTime)reader["date_added"];
            _item.isEnabled = int.Parse(reader["isenabled"].ToString());
            _item.isReviewed = int.Parse(reader["isreviewed"].ToString());
            _item.isExternal = int.Parse(reader["isexternal"].ToString());
            _item.Embed_Script = reader["embed_script"].ToString();
            _item.Categories = reader["categories"].ToString();
            _item.Type = Convert.ToInt32(reader["type"]);
            _item.Mode = Convert.ToInt32(reader["mode"]);
            _items.Add(_item);
                     
            
           
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }
  
    // Fetch video content info - require in order to delete video or process contents
    public static List<Video_Struct> Fetch_Video_Data(long VideoID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT username,thumbfilename,videofilename,originalvideofilename FROM videos WHERE VideoID=" + VideoID + "");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.UserName = reader["username"].ToString();
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.VideoFileName = reader["videofilename"].ToString();
            _item.OriginalVideoFileName = reader["originalvideofilename"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    public static List<Video_Struct> Load_Related_Videos(string title, string tags, long VideoID, int type, long AlbumID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        string term = title.Replace("'", "");
        int i = 0;
        int word_counter = 0;
        string _records = "TOP 20";

        str.Append("SELECT " + _records +  " VideoID,title,username,views,downloads,duration,thumbfilename,thumb_url,isexternal,embed_script,isFeatured,date_added FROM videos WHERE isPrivate=0 AND isEnabled=1 AND ispublished=1 AND isreviewed=1 AND VideoID<>@videoid AND type=@type");
        if (AlbumID > 0)
        {
            // if album id exist, load only album videos or audio files
            str.Append(" AND galleryid=" + AlbumID + "");
        }
        else
        {
            str.Append(" AND (");
            // search via video tags
            if (tags != "")
            {
                if (tags.Contains(","))
                {
                    string[] tg_arr = tags.Split(char.Parse(","));
                    i = 0;
                    word_counter = 0;
                    for (i = 0; i <= tg_arr.Length - 1; i++)
                    {
                        if (tg_arr[i].Length > 1)
                        {
                            if (word_counter == 0) // first word
                                str.Append(" tags like '%" + tg_arr[i].Trim().ToString().Replace("'", "") + "%'");
                            else
                                str.Append(" OR tags like '%" + tg_arr[i].Trim().ToString().Replace("'", "") + "%'");

                            word_counter++;
                        }
                    }
                }
                else
                {
                    str.Append(" tags like '%" + tags.Replace("'", "") + "%'");
                }
            }
            else
            {
                // if tags not found
                // search via video title
                if (title.Contains(" "))
                {
                    // split title into characters
                    string[] arr = title.Split(char.Parse(" "));
                    for (i = 0; i <= arr.Length - 1; i++)
                    {
                        if (arr[i].Length > 1)
                        {
                            if (word_counter == 0) // first word
                                str.Append("title like '%" + arr[i].Trim().ToString().Replace("'", "") + "%'");
                            else
                                str.Append(" OR title like '%" + arr[i].Trim().ToString().Replace("'", "") + "%'");

                            word_counter++;
                        }
                    }
                }
                else
                {
                    str.Append("title like '%" + title.Replace("'", "") + "%'");
                }
            }
            str.Append(")");
        }
        str.Append(" ORDER BY isfeatured desc, date_added desc, liked desc, views desc ");

        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        video_cmd.Parameters.Add(new SqlParameter("@type", type));
        video_cmd.Parameters.Add(new SqlParameter("@videoid", VideoID));
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["VideoID"];
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.isFeatured = Convert.ToInt32(reader["isfeatured"]);
            _item.Embed_Script = reader["embed_script"].ToString();
            _item.Date_Added = Convert.ToDateTime(reader["date_added"]);
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }


    // Load Top 4 Video Responses // display on video preview page.
    // Cache Version
    public static List<Video_Struct> Load_VideoResponses_SM(long VideoID,int type)
    {
         // cache implementation
        int cache_duration = Config.GetCacheDuration();
        if (cache_duration == 0) // no cache
            return VideoBLL.Load_VideoResponses_SM_NoCache(VideoID, type);
        else
        {
            if (HttpContext.Current.Cache["ld_vd_res_sm" + VideoID + "_" + type] == null)
            {
                HttpContext.Current.Cache.Add("ld_vd_res_sm" + VideoID + "_" + type, VideoBLL.Load_VideoResponses_SM_NoCache(VideoID, type), null, DateTime.Now.AddMinutes(cache_duration), TimeSpan.Zero, CacheItemPriority.High, null);
            }

            List<Video_Struct> _list = (List<Video_Struct>)(HttpContext.Current.Cache["ld_vd_res_sm" + VideoID + "_" + type]);
            return _list;
        }

    }
    // Load Top 4 Video Responses // display on video preview page
    // NoCache Version
    public static List<Video_Struct> Load_VideoResponses_SM_NoCache(long VideoID,int type)
    {

        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT TOP 4 VideoID,title,username,duration,views,downloads,thumbfilename,thumb_url,isexternal,embed_script FROM videos WHERE isPrivate=0 AND isEnabled=1 AND ispublished=1 AND isreviewed=1 AND response_videoid=" + VideoID + " AND type=" + type);
        str.Append(" ORDER BY date_added DESC");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["VideoID"];
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.isExternal = int.Parse(reader["isexternal"].ToString());
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.Embed_Script = reader["embed_script"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    // Load all video responses // display on video detail page.
    // Cache Version
    public static List<Video_Struct> Load_VideoResponses(long VideoID,int PageNumber,int PageSize,int type)
    {  
        // cache implementation
        string cache = "ld_vd_res_" + PageNumber + "" + VideoID + "_" + type;
        int cache_duration = Config.GetCacheDuration();
        if (cache_duration == 0) // no cache
            return VideoBLL.Load_VideoResponses_NoCache(VideoID, PageNumber, PageSize, type);
        else
        {
            if (HttpContext.Current.Cache[cache] == null)
            {
                HttpContext.Current.Cache.Add(cache, VideoBLL.Load_VideoResponses_NoCache(VideoID, PageNumber, PageSize, type), null, DateTime.Now.AddMinutes(cache_duration), TimeSpan.Zero, CacheItemPriority.High, null);
            }

            List<Video_Struct> _list = (List<Video_Struct>)(HttpContext.Current.Cache[cache]);
            return _list;
        }

    }

    // Load all video responses // display on video detail page.
    // NoCache Version
    public static List<Video_Struct> Load_VideoResponses_NoCache(long VideoID,int PageNumber, int PageSize,int type)
    {

        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;
       // generate sql query
        StringBuilder str = new StringBuilder();
        StringBuilder query = new StringBuilder();
        query.Append("VideoID,title,username,duration,views,downloads,thumbfilename,thumb_url,isexternal,embed_script FROM videos WHERE isPrivate=0 AND isEnabled=1 AND ispublished=1 AND isreviewed=1 AND response_videoid=" + VideoID + " AND type=" + type);
        // implement paging script for differnt data sources.
        switch (Config.Return_PaginationType())
        {
            case 0:
                // SQL SERVER 2005 or Later Supported Query
                str.Append(Pagination_Process.Prepare_SQLSERVER2005_Pagination(query.ToString(), "date_added DESC", PageNumber, PageSize));
                break;
            case 1:
                // MySQL Supported Query
                string mysql_query = "SELECT " + query.ToString() + " ORDER BY date_added DESC";
                str.Append(Pagination_Process.Prepare_MySQL_Pagination(mysql_query, PageNumber, PageSize));
                break;
            case 2:
                // SQL SERVER 2000 Supported Query
                string normal_query = "SELECT " + query.ToString() + " ORDER BY date_added DESC";
                str.Append(normal_query);
                break;
        }
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["VideoID"];
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Duration = reader["duration"].ToString();
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Views = (int)reader["views"];
            _item.Downloads = (int)reader["downloads"];
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.isExternal = int.Parse(reader["isexternal"].ToString());
            _item.Embed_Script = reader["embed_script"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }
       
    public static List<Archive_Struct> Load_Arch_List(int type, int records, bool isall)
    {
        // cache implementation
        int cache_duration = Config.GetCacheDuration();
        if (cache_duration == 0) // no cache
            return Fetch_Archive_List(type,records,isall);
        else
        {
            string cache_key = "ld_vd_arc_lst_" + type + "" + records + "" + isall;
            if (HttpContext.Current.Cache[cache_key] == null)
                HttpContext.Current.Cache.Add(cache_key, Fetch_Archive_List(type, records, isall), null, DateTime.Now.AddMinutes(cache_duration), TimeSpan.Zero, CacheItemPriority.High, null);

            List<Archive_Struct> _list = (List<Archive_Struct>)(HttpContext.Current.Cache[cache_key]);
            return _list;
        }

    }
    public static List<Archive_Struct> Fetch_Archive_List(int type, int records, bool isall)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Archive_Struct> _items = new List<Archive_Struct>();
        Archive_Struct _item;

        // SQL SERVER
        StringBuilder str = new StringBuilder();
        string _records = "";
        if (!isall)
            _records = "TOP " + records;
        str.Append("SELECT " + _records + " YEAR(date_added) as _dt,MONTH(date_added) as _mon from videos WHERE isPrivate=0 AND isEnabled=1 AND ispublished=1 AND isreviewed=1 Group By YEAR(date_added),MONTH(date_added) Order by Year(date_added) DESC,MONTH(date_added) DESC");
        // execute sql query
        SqlCommand blogs_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = blogs_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Archive_Struct();
            _item.Month = Convert.ToInt32(reader["_mon"]);
            _item.Year = Convert.ToInt32(reader["_dt"]);
            _item.MonthName = UtilityBLL.ReturnMonthName(_item.Month);

            _items.Add(_item);
        }

        ////MYSQL VERSION
        //StringBuilder str = new StringBuilder();
        //str.Append("SELECT YEAR(date_added) as _dt,MONTHNAME(date_added) as _mn,MONTH(date_added) as _mon from videos WHERE isPrivate=0 AND isEnabled=1 AND ispublished=1 AND isreviewed=1 Group By YEAR(date_added),MONTHNAME(date_added),MONTH(date_added) Order by Year(date_added) DESC,MONTH(date_added) DESC");
        //if (!isall)
        //    str.Append(" LIMIT " + records);
        //// execute sql query
        //SqlCommand blogs_cmd = new SqlCommand(str.ToString(), con);
        //SqlDataReader reader = blogs_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        //while (reader.Read())
        //{
        //    _item = new Archive_Struct();
        //    _item.Month = Convert.ToInt32(reader["_mon"]);
        //    _item.Year = Convert.ToInt32(reader["_dt"]);
        //    //_item.MonthName = Encoding.ASCII.GetString((byte[])reader["_mn"]).ToString(); 
        //    _item.MonthName = reader["_mn"].ToString(); 
        //    _items.Add(_item);
        //}

        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }
     
    public static List<Video_Struct> Get_SM_Info(long VideoID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;
        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT title,username,isenabled,type FROM videos WHERE videoid=" + VideoID + "");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.isEnabled = Convert.ToInt32(reader["isenabled"]);
            _item.Type = Convert.ToInt32(reader["type"]);
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }


	#endregion

    #region Youtube SDK
    //*********************
    // Youtube SDK Related
    //*********************
    public static bool Check_YOUTUBE_ID(string youtubeid)
    {
        int result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(videoid) from videos where youtubeid='" + youtubeid + "'"));
        if (result > 0)
            return true;
        else
            return false;
    }

    public static bool Check_YOUTUBE_ID(string youtubeid, int filter)
    {
        int result = 0;
        switch (filter)
        {
            case 0:
                // today
                result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(videoid) from videos where youtubeid='" + youtubeid + "' AND " + Config.Prepare_DateDiff("date_added", 0) + " "));
                break;
            case 1:
                // this week
                result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(videoid) from videos where youtubeid='" + youtubeid + "' AND " + Config.Prepare_DateDiff("date_added", 1) + " "));
                break;
            case 2:
                // this month
                result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(videoid) from videos where youtubeid='" + youtubeid + "' AND " + Config.Prepare_DateDiff("date_added", 2) + " "));
                break;
            case 3:
                // all time
                result = Convert.ToInt32(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Count(videoid) from videos where youtubeid='" + youtubeid + "'"));
                break;
        }

        if (result > 0)
            return true;
        else
            return false;
    }

    // VSK 5.5 Addition (Target Youtube Videos)
    // Fetch un processed video tags
    public static long Count_InactiveTag_Videos()
    {
        StringBuilder query = new StringBuilder();
        query.Append("SELECT Count(VideoID) FROM videos WHERE isEnabled=1 AND ispublished=1 AND isreviewed=1 AND istagsreviewed=1");

        return Convert.ToInt64(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, query.ToString()));

    }

    public static List<Video_Struct> Fetch_Inactive_Tags(int PageNumber, int PageSize)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        StringBuilder query = new StringBuilder();
        query.Append("tags,videoid FROM videos WHERE isEnabled=1 AND ispublished=1 AND isreviewed=1 AND istagsreviewed=1");
        // implement paging script for differnt data sources.
        switch (Config.Return_PaginationType())
        {
            case 0:
                // SQL SERVER 2005 or Later Supported Query
                str.Append(Pagination_Process.Prepare_SQLSERVER2005_Pagination(query.ToString(), "VideoID ASC", PageNumber, PageSize));
                break;
            case 1:
                // MySQL Supported Query
                string mysql_query = "SELECT " + query.ToString() + " ORDER BY VideoID ASC";
                str.Append(Pagination_Process.Prepare_MySQL_Pagination(mysql_query, PageNumber, PageSize));
                break;
            case 2:
                // SQL SERVER 2000 Supported Query
                string normal_query = "SELECT " + query.ToString() + " ORDER BY VideoID ASC";
                str.Append(normal_query);
                break;
        }
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.Tags = reader["tags"].ToString();
            _item.VideoID = Convert.ToInt64(reader["videoid"]);
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    // update un process tag status to process
    public static bool Update_Unreviewed_Tag_Status(long videoid)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set istagsreviewed=0 WHERE videoid=" + videoid + "");
        return true;
    }

    // Fetch All Youtube Ids
    public static List<Video_Struct> Fetch_YoutubeIDs(string categoryid, int PageNumber, int PageSize)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        StringBuilder query = new StringBuilder();
        query.Append("youtubeid,videoid FROM videos WHERE isEnabled=1 AND ispublished=1 AND isreviewed=1");
        if (categoryid != "all")
            query.Append(" AND categoryid=" + categoryid + "");
        // implement paging script for differnt data sources.
        switch (Config.Return_PaginationType())
        {
            case 0:
                // SQL SERVER 2005 or Later Supported Query
                str.Append(Pagination_Process.Prepare_SQLSERVER2005_Pagination(query.ToString(), "VideoID DESC", PageNumber, PageSize));
                break;
            case 1:
                // MySQL Supported Query
                string mysql_query = "SELECT " + query.ToString() + " ORDER BY VideoID DESC";
                str.Append(Pagination_Process.Prepare_MySQL_Pagination(mysql_query, PageNumber, PageSize));
                break;
            case 2:
                // SQL SERVER 2000 Supported Query
                string normal_query = "SELECT " + query.ToString() + " ORDER BY VideoID DESC";
                str.Append(normal_query);
                break;
        }
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = Convert.ToInt64(reader["videoid"]);
            _item.YoutubeID = reader["youtubeid"].ToString().Replace("/watch@v=", "");
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }
    
    #endregion

    // Fetch Recently Posted Videos
    public static List<Video_Struct> Fetch_Rec_Videos(int Records)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder query = new StringBuilder();
        query.Append("SELECT TOP " + Records + " videoid,title FROM videos WHERE isEnabled=1 AND ispublished=1 AND isreviewed=1 Order by videoid desc");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(query.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = Convert.ToInt64(reader["videoid"]);
            _item.Title = reader["title"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }
          
    public static List<Video_Struct> Load_Video_Basic_Information(long videoid)
    {
        // isfeatured values 2: all, 0: normal videos, 1: featured videos
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();

        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT title,username,description,tags,categoryid,categories,isprivate,thumbfilename,ispublished,iscomments,isresponse,isratings,embed_script,isexternal,thumb_url FROM videos WHERE videoid=" + videoid + "");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.Title = reader["title"].ToString();
            _item.Categories = reader["categories"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Description = reader["description"].ToString();
            _item.Tags = reader["tags"].ToString();
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.CategoryID = Convert.ToInt32(reader["categoryid"]);
            _item.isPrivate = Convert.ToInt32(reader["isprivate"]);
            _item.isPublished = Convert.ToInt32(reader["ispublished"]);
            _item.isComments = Convert.ToInt32(reader["iscomments"]);
            _item.isResponse = Convert.ToInt32(reader["isresponse"]);
            _item.isRatings = Convert.ToInt32(reader["isratings"]);
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.Embed_Script = reader["embed_script"].ToString();
            _items.Add(_item);
        }
        reader.Close();

        con.Close(); con.Dispose();

        return _items;
    }

    // Get Information For Download Media
    public static List<Video_Struct> Get_Download_File_Info(long videoid)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();

        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT title,username,downloads,type,videofilename,originalvideofilename,flv_url FROM videos WHERE videoid=" + videoid + "");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.Title = reader["title"].ToString();
            _item.Downloads = Convert.ToInt32(reader["downloads"]);
            _item.VideoFileName = reader["videofilename"].ToString();
            _item.OriginalVideoFileName = reader["originalvideofilename"].ToString();
            _item.FLV_Url = reader["flv_url"].ToString();
            _item.Type = Convert.ToInt32(reader["type"]);
            _item.UserName = reader["username"].ToString();
            _items.Add(_item);
        }
        reader.Close();

        con.Close(); con.Dispose();

        return _items;
    }


    // fetch video information for post preview
    public static List<Video_Struct> Fetch_Video_Info(long ID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;
        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT title,description,username,thumbfilename,thumb_url,views,liked,ispublished,isexternal,duration FROM videos WHERE videoid=" + ID + " AND isEnabled=1 AND ispublished=1 AND isreviewed=1");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Title = reader["title"].ToString();
            _item.Description = reader["Description"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.Views = Convert.ToInt32(reader["views"]);
            _item.Liked = Convert.ToInt32(reader["liked"]);
            _item.isPublished = Convert.ToInt32(reader["ispublished"]);
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.Duration = reader["duration"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }


    // Fetch photos for final settings - photos uploaded via uploader but still final settings remained
    public static List<Video_Struct> Fetch_Finalized_Videos(long GalleryID, int Records, string username, long MaxVideoID)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();

        str.Append("SELECT TOP " + Records + " videoid,title,description,username,thumbfilename,thumb_url,views,liked,ispublished,isexternal,duration,galleryid,type FROM videos WHERE videoid>@MaxVideoID AND");
        if (GalleryID > 0)
            str.Append(" galleryid=@galleryid");
        else
            str.Append(" username=@username");

        str.Append(" ORDER BY videoid desc");

        // execute sql query
        SqlCommand cmd = new SqlCommand(str.ToString(), con);
        cmd.Parameters.Add(new SqlParameter("@username", username));
        cmd.Parameters.Add(new SqlParameter("@galleryid", GalleryID));
        cmd.Parameters.Add(new SqlParameter("@MaxVideoID", MaxVideoID));
        SqlDataReader reader = cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = (long)reader["videoid"];
            _item.ThumbFileName = reader["thumbfilename"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.Title = reader["title"].ToString();
            _item.Description = reader["Description"].ToString();
            _item.Thumb_Url = reader["thumb_url"].ToString();
            _item.Views = Convert.ToInt32(reader["views"]);
            _item.Liked = Convert.ToInt32(reader["liked"]);
            _item.isPublished = Convert.ToInt32(reader["ispublished"]);
            _item.isExternal = Convert.ToInt32(reader["isexternal"]);
            _item.Duration = reader["duration"].ToString();
            _item.GalleryID = (long)reader["galleryid"];
            _item.Type = Convert.ToInt32(reader["type"]);
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }
    
    public static long MaxVideoID(string username)
    {
        long maxvidid = 0;
        int countvideos = Convert.ToInt32(members.Return_Value(username, "stat_videos"));
        if (countvideos > 0)
            maxvidid = Convert.ToInt64(SqlHelper.ExecuteScalar(Config.ConnectionString, CommandType.Text, "SELECT Max(videoid) FROM videos WHERE username=@username", new SqlParameter("@username", username)));

        return maxvidid;
    }


    // used to update photo info at time of final submission
    public static bool Update_Info(Video_Struct ph)
    {
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, "Update videos set title=@title,description=@description,tags=@tags,categories=@categories where videoid=@videoid", new SqlParameter("@title", ph.Title), new SqlParameter("@description", ph.Description),new SqlParameter("@videoid",ph.VideoID),new SqlParameter("@categories",ph.Categories),new SqlParameter("@tags",ph.Tags));
        return true;
    }


    // ********************************************
    // Fetch unpublished video and audio information
    // ********************************************
    public static List<Video_Struct> Fetch_UnPublished_Videos(int Records, int Type)
    {
        SqlConnection con = new SqlConnection(Config.ConnectionString);
        if (con.State != ConnectionState.Open) con.Open();
        List<Video_Struct> _items = new List<Video_Struct>();
        Video_Struct _item;

        // generate sql query
        StringBuilder str = new StringBuilder();
        str.Append("SELECT TOP " + Records + " videoid,title,username,originalvideofilename FROM videos WHERE ispublished=0 AND Type=@type Order By videoid desc");
        // execute sql query
        SqlCommand video_cmd = new SqlCommand(str.ToString(), con);
        video_cmd.Parameters.Add(new SqlParameter("@type", Type));
        SqlDataReader reader = video_cmd.ExecuteReader(CommandBehavior.CloseConnection);
        while (reader.Read())
        {
            _item = new Video_Struct();
            _item.VideoID = Convert.ToInt64(reader["videoid"]);
            _item.Title = reader["title"].ToString();
            _item.UserName = reader["username"].ToString();
            _item.OriginalVideoFileName = reader["originalvideofilename"].ToString();
            _items.Add(_item);
        }
        reader.Close();
        con.Close(); con.Dispose();

        return _items;
    }

    public static void Update_Unpublished_Video_Info(Video_Struct vd)
    {
        StringBuilder str = new StringBuilder();
        // insert new record
        str.Append("Update videos set VideoFileName=@VideoFileName,ThumbFileName=@ThumbFileName,isPublished=@isPublished,flv_url=@flv_url,thumb_url=@thumb_url,org_url=@org_url,errorcode=@errorcode Where VideoID=@VideoID");
        SqlHelper.ExecuteNonQuery(Config.ConnectionString, CommandType.Text, str.ToString(), new SqlParameter("@VideoFileName", vd.VideoFileName), new SqlParameter("@ThumbFileName", vd.ThumbFileName), new SqlParameter("@isPublished", vd.isPublished), new SqlParameter("@VideoID", vd.VideoID), new SqlParameter("@flv_url",vd.FLV_Url),new SqlParameter("@errorcode",vd.ErrorCode),new SqlParameter("@org_url",vd.Org_Url),new SqlParameter("@thumb_url",vd.Thumb_Url));
    }
}
